@@ -95,11 +95,18 @@ def unbalance_emai(y, xmat, zmat, kin, init=None, maxiter=30, cc_par=1.0e-8, cc_
         e = y - xmat.dot(eff[:eff_ind[0][1], :]) - zmat_con.dot(
             eff[eff_ind[0][1]:, :])
         # first-order derivative
+        out_file = 'test2'
         fd_mat = pre_fd_mat_x(cmati, kin, covi_mat, eff, eff_ind, e, cov_dim, zmat_con_lst, wmat, num_record, var_com)
+        np.savetxt(out_file + '.fd2', fd_mat)
         # AI matrix
         ai_mat = pre_ai_mat(cmati, covi_mat, eff, eff_ind, e, cov_dim, zmat_con_lst, wmat, var_com)
+        np.savetxt(out_file + '.ai2', ai_mat)
         # EM matrix
         em_mat = pre_em_mat(cov_dim, zmat_con_lst, num_record, var_com)
+        np.savetxt(out_file + '.em2', em_mat)
+        logging.info(fd_mat)
+        logging.info(ai_mat)
+        logging.info(em_mat)
         # Increase em weight to guarantee variances positive
         gamma = -em_weight_step
         while gamma < 1.0:
