@@ -1,5 +1,8 @@
 from gmat.remma.remma_add import remma_add
 from gmat.remma.remma_dom import remma_dom
 
+from gmat.remma.remma_add import _remma_add
+from gmat.remma.remma_dom import _remma_dom
+
 from gmat.remma.annotation import annotation_snp_pos
 from gmat.remma.random_pair import random_pair, random_pairAD
